@@ -1,4 +1,5 @@
 import threading
+from io import BytesIO
 
 import base58
 
@@ -8,10 +9,10 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import List, Union, Optional, Callable, Any
 
+from borsh_construct import CStruct, U32, U8
 from solana.rpc import commitment, types
 from solana.rpc.commitment import Confirmed
 from solana.rpc.websocket_api import connect as solana_ws_connect
-from solana.sysvar import SYSVAR_CLOCK_PUBKEY
 from solders.rpc.responses import AccountNotification, SubscriptionResult, SubscriptionError
 from spl.token import instructions as spl_token_instructions
 
@@ -511,8 +512,7 @@ class SDKTrader:
             risk_model_configuration_acct=sdk.risk_model_configuration_acct,
             risk_signer=sdk.risk_signer,
             capital_limits=sdk.capital_limits,
-            risk_state_account=self.trader_risk_state_acct,
-            clock=sdk.clock,
+            trader_risk_state_acct=self.trader_risk_state_acct,
             params=dtys.WithdrawFundsParams(
                 quantity=qty,
             ),
@@ -546,6 +546,7 @@ class SDKTrader:
                 ixs.append(a)
 
         ixs.insert(0, self._update_mark_prices_ix(sdk))
+        ixs.insert(0, self._request_compute_ix(sdk))
 
         trans_details = sdk.send_instructions(*ixs, raise_on_error=False)
         if trans_details.error:
@@ -562,6 +563,22 @@ class SDKTrader:
                 ) for idx, raw_summary in enumerate(trans_details.emitted_dex_order_summaries())
             ]
 
+    def _request_compute_ix(self, sdk: "SDKContext", units: int = 1400000):
+        request_units = CStruct(
+            "units" / U32,
+        )
+
+        buffer = BytesIO()
+        # this is the enum value for SetComputeUnitLimit
+        buffer.write(U8.build(2))
+        buffer.write(request_units.build({"units": units}))
+
+        return TransactionInstruction(
+            [],
+            PublicKey("ComputeBudget111111111111111111111111111111"),
+            buffer.getvalue()
+        )
+
     def place_order(
             self,
             sdk: "SDKContext",
@@ -569,7 +586,7 @@ class SDKTrader:
             side: aaob_state.Side,
             size: Union[dtys.Fractional, float],
             price: Union[dtys.Fractional, float],
-            self_trade_behavior: aaob_state.SelfTradeBehavior = aaob_state.SelfTradeBehavior.DECREMENT_TAKE,
+            self_trade_behavior: aaob_state.SelfTradeBehavior = aaob_state.SelfTradeBehavior.CANCEL_PROVIDE,
             order_type: dtys.OrderType = dtys.OrderType.LIMIT,
             batch_id: int = None
     ) -> SDKOrderSummary:
@@ -578,8 +595,9 @@ class SDKTrader:
         if batch_id is not None:
             self._pending_batches[batch_id].append(_PendingNewOrder(product, side, size, price, self_trade_behavior, order_type))
         else:
+            request_compute_ix = self._request_compute_ix(sdk, 800000)
             update_mark_prices_ix = self._update_mark_prices_ix(sdk)
-            trans_details = sdk.send_instructions(update_mark_prices_ix, ix, raise_on_error=False)
+            trans_details = sdk.send_instructions(request_compute_ix, update_mark_prices_ix, ix, raise_on_error=False)
             if trans_details.error:
                 raise ValueError(trans_details.error_from_log)
             else:
@@ -594,7 +612,7 @@ class SDKTrader:
             side: aaob_state.Side,
             size: Union[dtys.Fractional, float],
             price: Union[dtys.Fractional, float],
-            self_trade_behavior: aaob_state.SelfTradeBehavior = aaob_state.SelfTradeBehavior.DECREMENT_TAKE,
+            self_trade_behavior: aaob_state.SelfTradeBehavior = aaob_state.SelfTradeBehavior.CANCEL_PROVIDE,
             order_type: dtys.OrderType = dtys.OrderType.LIMIT,
             risk_accounts: Optional[List[PublicKey]] = None,
     ):
@@ -621,7 +639,6 @@ class SDKTrader:
             risk_output_register=sdk.risk_output_register,
             trader_risk_state_acct=self.trader_risk_state_acct,
             risk_and_fee_signer=sdk.risk_signer,
-            clock=sdk.clock,
             params=dtys.NewOrderParams(
                 side=side,
                 max_base_qty=dtys.Fractional.into(size, product.metadata.base_decimals),
@@ -680,7 +697,6 @@ class SDKTrader:
             risk_output_register=sdk.risk_output_register,
             trader_risk_state_acct=self.trader_risk_state_acct,
             risk_and_fee_signer=sdk.risk_signer,
-            clock=sdk.clock,
             remaining_accounts=remaining_accounts
         )
 
@@ -696,7 +712,6 @@ class SDKTrader:
             payer=self.keypair.public_key,
             mark_prices=sdk.additional_risk_accts[2],
             market_product_group=sdk.market_product_group,
-            clock=sdk.clock,
             remaining_accounts=remaining_accounts,
         )
 
@@ -726,9 +741,7 @@ class SDKTrader:
             risk_output_register=sdk.risk_output_register,
             trader_risk_state_acct=self.trader_risk_state_acct,
             risk_signer=sdk.risk_signer,
-            clock=sdk.clock,
             params=CancelOrderParams(order_id=order_id, no_err=no_err),
-            system_program=SYS_PROGRAM_ID,
             remaining_accounts=None,
             program_id=sdk.dex_program,
         )
@@ -751,7 +764,7 @@ class SDKTrader:
             side: aaob_state.Side,
             size: Union[dtys.Fractional, float],
             price: Union[dtys.Fractional, float],
-            self_trade_behavior: aaob_state.SelfTradeBehavior = aaob_state.SelfTradeBehavior.DECREMENT_TAKE,
+            self_trade_behavior: aaob_state.SelfTradeBehavior = aaob_state.SelfTradeBehavior.CANCEL_PROVIDE,
             order_type: dtys.OrderType = dtys.OrderType.LIMIT,
             batch_id: int = None,
             cancel_no_err: bool = True,
@@ -764,8 +777,9 @@ class SDKTrader:
             self._pending_batches[batch_id].append(cancel_ix)
             self._pending_batches[batch_id].append(_PendingNewOrder(product, side, size, price, self_trade_behavior, order_type))
         else:
+            request_compute_ix = self._request_compute_ix(sdk, 800000)
             update_mark_prices_ix = self._update_mark_prices_ix(sdk)
-            trans_details = sdk.send_instructions(update_mark_prices_ix, cancel_ix, place_ix, raise_on_error=False)
+            trans_details = sdk.send_instructions(request_compute_ix, update_mark_prices_ix, cancel_ix, place_ix, raise_on_error=False)
             if trans_details.error:
                 raise Exception(trans_details.error_from_log)
             else:
@@ -894,7 +908,6 @@ class SDKContext:
     risk_output_register: PublicKey
     fee_output_register: PublicKey
     fee_collector: PublicKey
-    clock: PublicKey
     mark_price_accounts: List[PublicKey]
     price_oracle_accounts: List[PublicKey]
     additional_risk_accts: List[PublicKey]
@@ -972,7 +985,6 @@ class SDKContext:
             risk_output_register=mpg.risk_output_register,
             fee_output_register=mpg.fee_output_register,
             fee_collector=mpg.fee_collector,
-            clock=SYSVAR_CLOCK_PUBKEY,
             mark_price_accounts=list(),
             price_oracle_accounts=list(),
             additional_risk_accts=[s_account, r_account, mark_prices_account],
@@ -1015,7 +1027,6 @@ class SDKContext:
         products = []
         mark_price_accounts = []
         price_oracle_accounts = []
-        clock = SYSVAR_CLOCK_PUBKEY
 
         mark_prices: MarkPricesArray = fetch_account_details(self.additional_risk_accts[2]).data_obj
         if mark_prices.is_hardcoded_oracle:
@@ -1044,10 +1055,8 @@ class SDKContext:
                 derivative_metadata: DerivativeMetadata = fetch_account_details(metadata.product_key).data_obj
                 mark_price_accounts.append(metadata.product_key)
                 price_oracle_accounts.append(derivative_metadata.price_oracle)
-                clock = derivative_metadata.clock
 
         self.products = products
-        self.clock = clock
         self.mark_price_accounts = mark_price_accounts
         self.price_oracle_accounts = price_oracle_accounts
 
@@ -1055,7 +1064,6 @@ class SDKContext:
         return solana_utils.send_instructions(*ixs, **kwargs)
 
     def register_trader(self, keypair: Keypair):
-        from solana.system_program import SYS_PROGRAM_ID
         trader_risk_group = Keypair.generate()
         trader_risk_state_acct = Keypair.generate()
         _ident = keypair.public_key.to_base58()[:8]
